@@ -6,7 +6,7 @@ const BASE_URL: &str = "https://contract.mexc.com";
 
 /// MXC Swap market.
 ///
-/// * REST API doc: <https://github.com/mxcdevelop/APIDoc/blob/master/contract/contract-api.md>
+/// * REST API doc: <https://mxcdevelop.github.io/APIDoc/>
 /// * Trading at: <https://contract.mxc.com/exchange>
 pub struct MxcSwapRestClient {
     _api_key: Option<String>,
@@ -30,10 +30,12 @@ impl MxcSwapRestClient {
 
     /// Get the latest Level2 snapshot of orderbook.
     ///
-    /// Top 1000 bids and asks will be returned.
+    /// Top 2000 bids and asks will be returned.
     ///
-    /// For example: <https://contract.mxc.com/api/v1/contract/depth_commits/BTC_USDT/1000>
+    /// For example: <https://contract.mxc.com/api/v1/contract/depth/BTC_USDT?limit=2000>
+    ///
+    /// Rate limit: 20 times /2 seconds
     pub fn fetch_l2_snapshot(symbol: &str) -> Result<String> {
-        gen_api!(format!("/api/v1/contract/depth_commits/{}/1000", symbol))
+        gen_api!(format!("/api/v1/contract/depth/{}?limit=2000", symbol))
     }
 }
